@@ -1,8 +1,11 @@
 """root of the package"""
+from .extracter import OFFICIAL_FILE_NAME, OFFICIAL_URL
 from .resolver import Resolver, read_csv_file, read_official_URL
 
 __all__ = [
     "read_csv_file",
     "read_official_URL",
     "Resolver",
+    "OFFICIAL_FILE_NAME",
+    "OFFICIAL_URL",
 ]
